% Define the composition (Archon, from Griffin et al., 2003)

LambOL=0.60;
LambCPX=0.11;
LambOPX=0.17;
LambGR=0.12;

% Define the percentage of Fe in the rock

% Archon
 LambFe=0.101;

% Define temperature range of calculation (25C-1800C,step 5C)

Trange=[298:5:2073];
Trange=Trange';

% Define pressure at 100 km
P=6.44*10.^9;

% Define the surface shear modulus (mi) of the single rock's component(Cammarano et
% al., 2003) 

miOL0=(81-(31*(LambFe))).*10.^9;
miCPX0=(67-(6*(LambFe))).*10.^9;
miOPX0=(75+(10*(LambFe))).*10.^9;
miGR0=(92+(7*(LambFe))).*10.^9;

% Define the temperature derivates of the shear modulus (mi) of the single
% rock's component (Cammarano et al., 2003)

miOLdev=-0.014.*10.^9;
miCPXdev=-0.010.*10.^9;
miOPXdev=-0.012.*10.^9;
miGRdev=-0.010.*10.^9;

% Define the pressure derivates of the shear modulus (mi) of the single
% rock's component (Cammarano et al., 2003)

miOLdevP=1.4;
miCPXdevP=1.7;
miOPXdevP=1.6;
miGRdevP=1.4;

miOL=miOL0+Trange.*miOLdev+P.*miOLdevP;
miCPX=miCPX0+Trange.*miCPXdev+P.*miCPXdevP;
miOPX=miOPX0+Trange.*miOPXdev+P.*miOPXdevP;
miGR=miGR0+Trange.*miGRdev+P.*miGRdevP;

% Calculate the average of the mean elastic parameters for a constant
% stress (Reuss) and a constant strain (Voigt)for S-wave (M=mi)

MReussMi=(LambOL./(miOL)+LambCPX./(miCPX)+LambOPX./(miOPX)+LambGR./(miGR));
MReussMi=MReussMi.^-1;
MVoigtMi=(LambOL.*(miOL)+LambCPX.*(miCPX)+LambOPX.*(miOPX)+LambGR.*(miGR));
Mi=0.5.*(MVoigtMi+MReussMi);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Define surface Temperature

T=298;

% Define coefficients to calculate alfa for each component of the rock
% (from Vacher et al., 1998)

%Olivine

aOL=(2.832.*10.^-5);
bOL=(0.758.*10.^-8);
cOL=0;
dOL=0;

% CPX

aCPX=(3.206.*10.^-5);   
bCPX=(0.811.*10.^-8);
cCPX=1.8167;
dCPX=(0.1347.*10.^-2);

%OPX

aOPX=(2.86.*10.^-5); 
bOPX=(0.72.*10.^-8);
cOPX=0;
dOPX=0;

%Garnet

aGR=(2.81.*10.^-5);  
bGR=(0.316.*10.^-8);
cGR=0.4587;
dGR=0;

% Define alfa for each component of the rock at temperature 298k

alfaOL=aOL+(bOL.*T)+(cOL.*T.^-2)+(dOL.*T.^-1);
alfaCPX=aCPX+(bCPX.*T)+(cCPX.*T.^-2)+(dCPX.*T.^-1);
alfaOPX=aOPX+(bOPX.*T)+(cOPX.*T.^-2)+(dOPX.*T.^-1);
alfaGR=aGR+(bGR.*T)+(cGR.*T.^-2)+(dGR.*T.^-1);

% Define <alfa> for the Pyrolite at temperature 298k

alfa=(alfaOL.*LambOL)+(alfaCPX.*LambCPX)+(alfaOPX.*LambOPX)+(alfaGR.*LambGR);

% Define the density of the single component of the rock Pyrolite at temperature
% 298k (Cammarano et al., 2003)

roOl=(3.222+1.182*(LambFe)).*10.^3;
roCPX=(3.277+0.38*(LambFe)).*10.^3;
roOPX=(3.215+0.799*(LambFe)).*10.^3;
roGR=(3.565+0.76*(LambFe)).*10.^3;

% Calculate the average density of the rock Pyrolite at temperature
% 298k

ro=((LambOL.*roOl)+(LambCPX.*roCPX)+(LambOPX.*roOPX)+(LambGR.*roGR));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Define the surface bulk modulus (Ks) of the single rock's component(Cammarano et al., 2003) 

KsOl0=129.*10.^9;
KsCPX0=(105+12*(LambFe)).*10.^9;
KsOPX0=(109+20*(LambFe)).*10.^9;
KsGR0=(171+15*(LambFe)).*10.^9;

% Define the pressure derivates of the bulk modulus (Ks) of the single
% rock's component(Cammarano et al., 2003)

KsPOldev=4.2;
KsPCPXdev=6.2-1.9*(LambFe);
KsPOPXdev=7.0;
KsPGRdev=4.4;

% Define the temperature derivates of the bulk modulus (Ks) of the single
% rock's component(Cammarano et al., 2003)

KsOldev=-0.017.*10.^9;
KsCPXdev=-0.013.*10.^9;
KsOPXdev=-0.027.*10.^9;
KsGRdev=-0.019.*10.^9;

% Estimate the average of the bulk modulus (Ks) of  the single
% rock's component

KsOl=KsOl0+Trange.*KsOldev+P.*KsPOldev;
KsCPX=KsCPX0+Trange.*KsCPXdev+P.*KsPCPXdev;
KsOPX=KsOPX0+Trange.*KsOPXdev+P.*KsPOPXdev;
KsGR=KsGR0+Trange.*KsGRdev+P.*KsPGRdev;

% Calculate the average of the mean elastic parameters for a constant
% stress (Reuss) and a constant strain (Voigt)for P-wave 

MReuss=(LambOL./(KsOl)+LambCPX./(KsCPX)+LambOPX./(KsOPX)+LambGR./(KsGR));
MReuss=MReuss.^-1;
MVoigt=(LambOL.*(KsOl)+LambCPX.*(KsCPX)+LambOPX.*(KsOPX)+LambGR.*(KsGR));
M=0.5.*(MVoigt+MReuss);

% Calculate density(T) using: Roi=Ro0(1-alfa0(T-T0)+ P-P0/K) (Goes et al., 2000)
density=ro.*(1-alfa.*(Trange-T)+P./M);

% Plot the density depending on temperature at a specific depth

figure
plot(Trange-T,density,'LineWidth',1)
% Create xlabel
xlabel('Temperature (C)','FontSize',20,'FontWeight','bold');
% Create ylabel
ylabel('Density (kg/m3)','FontSize',20,'FontWeight','bold');
% Create title
title('Tecton composition, Depth:200 km','FontSize',20,'FontWeight','bold');

% Estimate the synthetic velocity
Vs=(Mi./density).^0.5;

% Plot the elastic moulus Mi depending on temperature at a specific depth

figure
plot(Trange-T,Mi,'LineWidth',1)
% Create xlabel
xlabel('Temperature (C)','FontSize',20,'FontWeight','bold');
% Create ylabel
ylabel('Mi (Pa)','FontSize',20,'FontWeight','bold');
% Create title
title('Tecton composition, Depth:200 km','FontSize',20,'FontWeight','bold');

% plot the anharmonic velocity
figure
plot(Trange-T,Vs,'LineWidth',1)
% Create xlabel
xlabel('Temperature (C)','FontSize',20,'FontWeight','bold');
% Create ylabel
ylabel('Vs (m/s)','FontSize',20,'FontWeight','bold');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This program calculate the synthetic velocity for
% anelasticity 

% Define the values of the parameters to calculate Qs (model Q4)

g=30;
ome=1;
a1=0.20;
A=0.035;

% Estimate the solidus temperature (from Hirschmann, 2000)

% Define the coefficient of the equation

a=-5.104;
b=132.899;
c=1120.661;

% Define the pressure in GPa

P1=P/10^9;

Tm=a*P1^2+b*P1+c;

% Calculate Qs

Qs=A.*ome.^a1.*exp(a1.*g.*(Tm./Trange));

% Calculate Vsynth for anaharmonicity and anelasticity

VsynthS=Vs.*(1-((Qs.^-1)./(2.*tan(pi.*a1./2))));

% plot the anelasic velocity 

hold on

plot(Trange-T,VsynthS,'LineWidth',1)
% Create legend
legend({'Anharmonic Velocity (m/s)','Anelastic Velocity (m/s)'},'FontSize',20,'FontWeight','bold')
% Create Title
% Create title
title('Tecton composition, Depth:200 km','FontSize',20,'FontWeight','bold');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Estimate the temperature

% load the file of seismic velocity (Lon,Lat,Vs100km,Vs200km)

load VelNaA.dat

VelNa200=VelNaA(:,4).*1000;

% Initialize the matrix

MagT=zeros(length(VelNaA),3);

% Interpolate the temperature using the seismic tomkography data

for i=1:length(VelNaA)
    
TempFin200=interp1(VsynthS,Trange,VelNa200(i,1));
MagT(i,3)=TempFin200;

end

% Associate the coordinates of the data points to the first two columns of the T vector 
MagT(:,1)=VelNaA(:,1);
MagT(:,2)=VelNaA(:,2);


figure
plot(VelNa200,MagT(:,3), 'o')
xlabel('Temperature (C)','FontSize',20,'FontWeight','bold');
ylabel('Velocity (m/s)','FontSize',20,'FontWeight','bold');
% Create legend
legend({'Vs (m/s) vs T (C) at a depth of 200 km'},'FontSize',20,'FontWeight','bold')
% Create title
title('Tecton composition, Depth:200 km','FontSize',20,'FontWeight','bold');

% Find the points where the T > 1300C and associate the va1ue 1300 C
ExcT1=find(MagT(:,3)>1300);
MagT(ExcT1,3)=1300;

figure
plot(VelNa200,MagT(:,3), 'o')
xlabel('Temperature (C)','FontSize',20,'FontWeight','bold');
ylabel('Velocity (m/s)','FontSize',20,'FontWeight','bold');
% Create legend
legend({'Vs (m/s) vs T (C) at a depth of 200 km'},'FontSize',20,'FontWeight','bold')
% Create title
title('Tecton composition, Depth:200 km','FontSize',20,'FontWeight','bold');

% Save the temperature estimates
save FinalTempNaTecton200Km.dat MagT -ASCII